==> chwala_0.2.orig.tar.gz: chwala-0.2/lib/locale/en_US.php <==
<?php

$LANG['about.community'] = 'This is the Community Edition of the <b>Kolab Server</b>.';
$LANG['about.warranty'] = 'Professional support is available from <a href="http://kolabsys.com">Kolab Systems</a>.';
$LANG['about.support'] = 'It comes with absolutely <b>no warranties</b> and is typically run entirely self supported. You can find help &amp; information on the community <a href="http://kolab.org">web site</a> &amp; <a href="http://wiki.kolab.org">wiki</a>.';

$LANG['collection.audio'] = 'Audio';
$LANG['collection.video'] = 'Video';
$LANG['collection.image'] = 'Images';
$LANG['collection.document'] = 'Documents';

$LANG['file.copy'] = 'Copy';
$LANG['file.create'] = 'Create File';
$LANG['file.download'] = 'Download';
$LANG['file.edit'] = 'Edit';
$LANG['file.upload'] = 'Upload File';
$LANG['file.name'] = 'Name';
$LANG['file.move'] = 'Move';
$LANG['file.mtime'] = 'Modified';
$LANG['file.size'] = 'Size';
$LANG['file.open'] = 'Open';
$LANG['file.delete'] = 'Delete';
$LANG['file.rename'] = 'Rename';
$LANG['file.search'] = 'Search file';
$LANG['file.type'] = 'Type';
$LANG['file.save'] = 'Save';
$LANG['file.skip'] = 'Skip';
$LANG['file.skipall'] = 'Skip all';
$LANG['file.overwrite'] = 'Overwrite';
$LANG['file.overwriteall'] = 'Overwrite all';
$LANG['file.moveconfirm'] = 'This action is going to overwrite the destination file: <b>$file</b>.';
$LANG['file.progress'] = 'Uploaded $current of $total ($percent%)';

$LANG['folder.createtitle'] = 'Create Folder';
$LANG['folder.delete'] = 'Delete';
$LANG['folder.edit'] = 'Edit';
$LANG['folder.edittitle'] = 'Edit Folder';
$LANG['folder.under'] = 'under current folder';

$LANG['form.submit'] = 'Submit';
$LANG['form.cancel'] = 'Cancel';

$LANG['login.username'] = 'Username';
$LANG['login.password'] = 'Password';
$LANG['login.login'] = 'Log in';

$LANG['reqtime'] = 'Request time: $1 sec.';
$LANG['maxupload'] = 'Maximum file size: $1';
$LANG['internalerror'] = 'Internal system error!';
$LANG['loginerror'] = 'Incorrect username or password!';
$LANG['loading'] = 'Loading...';
$LANG['saving'] = 'Saving...';
$LANG['deleting'] = 'Deleting...';
$LANG['copying'] = 'Copying...';
$LANG['moving'] = 'Moving...';
$LANG['logout'] = 'Logout';
$LANG['close'] = 'Close';
$LANG['servererror'] = 'Server Error!';
$LANG['session.expired'] = 'Session has expired. Login again, please';

$LANG['search'] = 'Search';
$LANG['search.loading'] = 'Searching...';
$LANG['search.in_all_folders'] = 'in all folders';
$LANG['search.in_current_folder'] = 'in current folder';

$LANG['size.B'] = 'B';
$LANG['size.KB'] = 'KB';
$LANG['size.MB'] = 'MB';
$LANG['size.GB'] = 'GB';

$LANG['upload.size'] = 'Size:';
$LANG['upload.progress'] = 'Progress:';
$LANG['upload.rate'] = 'Rate:';
$LANG['upload.eta'] = 'ETA:';

==> chwala_0.4~dev20160427.orig.tar.gz: chwala-0.4/lib/locale/en_US.php <==
<?php

$LANG['about.community'] = 'This is the Community Edition of the <b>Kolab Server</b>.';
$LANG['about.warranty'] = 'Professional support is available from <a href="http://kolabsys.com">Kolab Systems</a>.';
$LANG['about.support'] = 'It comes with absolutely <b>no warranties</b> and is typically run entirely self supported. You can find help &amp; information on the community <a href="http://kolab.org">web site</a> &amp; <a href="http://wiki.kolab.org">wiki</a>.';

$LANG['collection.audio'] = 'Audio';
$LANG['collection.video'] = 'Video';
$LANG['collection.image'] = 'Images';
$LANG['collection.document'] = 'Documents';

$LANG['file.copy'] = 'Copy';
$LANG['file.create'] = 'Create File';
$LANG['file.download'] = 'Download';
$LANG['file.edit'] = 'Edit';
$LANG['file.upload'] = 'Upload File';
$LANG['file.name'] = 'Name';
$LANG['file.move'] = 'Move';
$LANG['file.mtime'] = 'Modified';
$LANG['file.size'] = 'Size';
$LANG['file.open'] = 'Open';
$LANG['file.delete'] = 'Delete';
$LANG['file.rename'] = 'Rename';
$LANG['file.search'] = 'Search file';
$LANG['file.type'] = 'Type';
$LANG['file.save'] = 'Save';
$LANG['file.skip'] = 'Skip';
$LANG['file.skipall'] = 'Skip all';
$LANG['file.overwrite'] = 'Overwrite';
$LANG['file.overwriteall'] = 'Overwrite all';
$LANG['file.moveconfirm'] = 'This action is going to overwrite the destination file: <b>$file</b>.';
$LANG['file.progress'] = 'Uploaded $current of $total ($percent%)';

$LANG['folder.createtitle'] = 'Create Folder';
$LANG['folder.delete'] = 'Delete';
$LANG['folder.edit'] = 'Edit';
$LANG['folder.edittitle'] = 'Edit Folder';
$LANG['folder.under'] = 'inside the current folder';
$LANG['folder.driverselect'] = 'bind with the external storage';
$LANG['folder.driverwithpass'] = 'remember password';
$LANG['folder.driverwithpassdesc'] = 'Stored passwords will be encrypted. Enable this if you do not want to be asked for the password on every login or you want this storage to be available via WebDAV.';
$LANG['folder.name'] = 'Name:';
$LANG['folder.authenticate'] = 'Logon to $title';
$LANG['folder.parent'] = 'Subfolder of:';

$LANG['form.submit'] = 'Submit';
$LANG['form.cancel'] = 'Cancel';
$LANG['form.hostname'] = 'Hostname:';
$LANG['form.username'] = 'Username:';
$LANG['form.password'] = 'Password:';
$LANG['form.baseuri'] = 'Base URI:';

$LANG['login.username'] = 'Username';
$LANG['login.password'] = 'Password';
$LANG['login.login'] = 'Log in';

$LANG['reqtime'] = 'Request time: $1 sec.';
$LANG['maxupload'] = 'Maximum file size: $1';
$LANG['internalerror'] = 'Internal system error!';
$LANG['loginerror'] = 'Incorrect username or password!';
$LANG['authenticating'] = 'Authenticating...';
$LANG['loading'] = 'Loading...';
$LANG['saving'] = 'Saving...';
$LANG['deleting'] = 'Deleting...';
$LANG['copying'] = 'Copying...';
$LANG['moving'] = 'Moving...';
$LANG['logout'] = 'Logout';
$LANG['close'] = 'Close';
$LANG['servererror'] = 'Server Error!';
$LANG['session.expired'] = 'Session has expired. Login again, please';
$LANG['localstorage'] = 'local storage';

$LANG['search'] = 'Search';
$LANG['search.loading'] = 'Searching...';
$LANG['search.in_all_folders'] = 'in all folders';
$LANG['search.in_current_folder'] = 'in current folder';

$LANG['size.B'] = 'B';
$LANG['size.KB'] = 'KB';
$LANG['size.MB'] = 'MB';
$LANG['size.GB'] = 'GB';

$LANG['upload.size'] = 'Size:';
$LANG['upload.size.error'] = 'Maximum upload size ($size) exceeded!';
$LANG['upload.progress'] = 'Progress:';
$LANG['upload.rate'] = 'Rate:';
$LANG['upload.eta'] = 'ETA:';
